@@ -33,7 +33,7 @@ class Application extends Container implements ApplicationContract, CachesConfig
      *
      * @var string
      */
-    const VERSION = '7.1.0';
+    const VERSION = '7.4.0';
 
     /**
      * The base path for the Laravel installation.
@@ -147,6 +147,13 @@ class Application extends Container implements ApplicationContract, CachesConfig
      */
     protected $namespace;
 
+    /**
+     * The prefixes of absolute cache paths for use during normalization.
+     *
+     * @var array
+     */
+    protected $absoluteCachePathPrefixes = [DIRECTORY_SEPARATOR];
+
     /**
      * Create a new Illuminate application instance.
      *
@@ -1010,11 +1017,24 @@ class Application extends Container implements ApplicationContract, CachesConfig
             return $this->bootstrapPath($default);
         }
 
-        return Str::startsWith($env, '/')
+        return Str::startsWith($env, $this->absoluteCachePathPrefixes)
                 ? $env
                 : $this->basePath($env);
     }
 
+    /**
+     * Add new prefix to list of absolute path prefixes.
+     *
+     * @param  string  $prefix
+     * @return $this
+     */
+    public function addAbsoluteCachePathPrefix($prefix)
+    {
+        $this->absoluteCachePathPrefixes[] = $prefix;
+
+        return $this;
+    }
+
     /**
      * Determine if the application is currently down for maintenance.
      *
